"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Button = void 0;
const react_1 = __importStar(require("react"));
const loader_1 = require("../loader");
const Theme_1 = require("../theme/Theme");
const typography_1 = require("../typography");
const util_1 = require("../util");
const composeEventHandlers_1 = require("../util/composeEventHandlers");
/**
 * A button component
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/button)
 * @see 🏷️ {@link ButtonProps}
 * @see [🤖 OverridableComponent](https://aksel.nav.no/grunnleggende/kode/overridablecomponent) support
 * @example
 * ```jsx
 * <Button>Klikk meg</Button>
 * ```
 */
exports.Button = (0, react_1.forwardRef)((_a, ref) => {
    var { as: Component = "button", variant = "primary", className, children, size = "medium", loading = false, disabled, icon, iconPosition = "left", onKeyUp, "data-color": color } = _a, rest = __rest(_a, ["as", "variant", "className", "children", "size", "loading", "disabled", "icon", "iconPosition", "onKeyUp", "data-color"]);
    const { cn } = (0, Theme_1.useRenameCSS)();
    const filterProps = disabled || loading ? (0, util_1.omit)(rest, ["href"]) : rest;
    const handleKeyUp = (e) => {
        if (e.key === " " && !disabled && !loading) {
            e.currentTarget.click();
        }
    };
    return (react_1.default.createElement(Component, Object.assign({}, (Component !== "button" ? { role: "button" } : {}), { "data-color": color !== null && color !== void 0 ? color : variantToColor(variant), "data-variant": variantToSimplifiedVariant(variant) }, filterProps, { ref: ref, onKeyUp: (0, composeEventHandlers_1.composeEventHandlers)(onKeyUp, handleKeyUp), className: cn(className, "navds-button", `navds-button--${variant}`, `navds-button--${size}`, {
            "navds-button--loading": loading,
            "navds-button--icon-only": !!icon && !children,
            "navds-button--disabled": disabled !== null && disabled !== void 0 ? disabled : loading,
        }), disabled: (disabled !== null && disabled !== void 0 ? disabled : loading) ? true : undefined }),
        icon && iconPosition === "left" && (react_1.default.createElement("span", { className: cn("navds-button__icon") }, icon)),
        loading && react_1.default.createElement(loader_1.Loader, { size: size }),
        children && (react_1.default.createElement(typography_1.Label, { as: "span", size: size === "medium" ? "medium" : "small" }, children)),
        icon && iconPosition === "right" && (react_1.default.createElement("span", { className: cn("navds-button__icon") }, icon))));
});
function variantToColor(variant) {
    switch (variant) {
        case "primary-neutral":
        case "secondary-neutral":
        case "tertiary-neutral":
            return "neutral";
        case "danger":
            return "danger";
        default:
            return undefined;
    }
}
function variantToSimplifiedVariant(variant) {
    switch (variant) {
        case "primary":
        case "primary-neutral":
        case "danger":
            return "primary";
        case "secondary":
        case "secondary-neutral":
            return "secondary";
        case "tertiary":
        case "tertiary-neutral":
            return "tertiary";
        default:
            return "primary";
    }
}
exports.default = exports.Button;
//# sourceMappingURL=Button.js.map