"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatePicker = void 0;
const date_fns_1 = require("date-fns");
const react_1 = __importStar(require("react"));
const Theme_1 = require("../../theme/Theme");
const hooks_1 = require("../../util/hooks");
const useMergeRefs_1 = require("../../util/hooks/useMergeRefs");
const i18n_hooks_1 = require("../../util/i18n/i18n.hooks");
const Date_Dialog_1 = require("../Date.Dialog");
const Date_Input_1 = require("../Date.Input");
const Date_locale_1 = require("../Date.locale");
const Date_typeutils_1 = require("../Date.typeutils");
const DatePicker_RDP_1 = require("./parts/DatePicker.RDP");
const DatePicker_Standalone_1 = __importDefault(require("./parts/DatePicker.Standalone"));
/**
 * A component that allows users to select a date from a calendar.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/datepicker)
 * @see 🏷️ {@link DatePickerProps}
 *
 * @example
 * ```jsx
 *  const { inputProps, datepickerProps } = useMonthpicker({
 *    onMonthChange: console.log,
 *  });
 *
 *  return (
 *     <DatePicker {...datepickerProps} dropdownCaption>
 *       <DatePicker.Input
 *         {...inputProps}
 *         label="Velg dato"
 *       />
 *     </DatePicker>
 *  );
 * ```
 */
exports.DatePicker = (0, react_1.forwardRef)((_a, ref) => {
    var { children, locale, translations, selected, id, defaultSelected, wrapperClassName, open: _open, onClose, onOpenToggle, strategy, mode } = _a, rest = __rest(_a, ["children", "locale", "translations", "selected", "id", "defaultSelected", "wrapperClassName", "open", "onClose", "onOpenToggle", "strategy", "mode"]);
    const translate = (0, i18n_hooks_1.useI18n)("DatePicker", translations, (0, Date_locale_1.getTranslations)(locale));
    const { cn } = (0, Theme_1.useRenameCSS)();
    const ariaId = (0, hooks_1.useId)(id);
    const [open, setOpen] = (0, hooks_1.useControllableState)({
        defaultValue: false,
        value: _open,
    });
    /* We use state here to insure that anchor is defined if open is true on initial render */
    const [wrapperRef, setWrapperRef] = (0, react_1.useState)(null);
    const mergedRef = (0, useMergeRefs_1.useMergeRefs)(setWrapperRef, ref);
    const [value, setValue] = (0, hooks_1.useControllableState)({
        defaultValue: defaultSelected,
        value: selected,
        onChange: (newValue) => {
            var _a;
            let closeDialog = false;
            if (mode === "single" && newValue) {
                closeDialog = true;
            }
            else if ((0, Date_typeutils_1.isDateRange)(newValue) && newValue.from && newValue.to) {
                closeDialog = true;
                if ((0, date_fns_1.isSameDay)(newValue.from, newValue.to)) {
                    closeDialog = false;
                }
            }
            if (closeDialog) {
                onClose === null || onClose === void 0 ? void 0 : onClose();
                setOpen(false);
            }
            (_a = rest === null || rest === void 0 ? void 0 : rest.onSelect) === null || _a === void 0 ? void 0 : _a.call(rest, newValue);
        },
    });
    return (react_1.default.createElement(Date_locale_1.DateTranslationContextProvider, { translate: translate },
        react_1.default.createElement(Date_Input_1.DateInputContextProvider, { open: open, onOpen: () => {
                setOpen((x) => !x);
                onOpenToggle === null || onOpenToggle === void 0 ? void 0 : onOpenToggle();
            }, ariaId: ariaId, defined: true },
            react_1.default.createElement("div", { ref: mergedRef, className: cn("navds-date__wrapper", wrapperClassName) },
                children,
                react_1.default.createElement(Date_Dialog_1.DateDialog, { open: open, anchor: wrapperRef, onClose: () => {
                        onClose === null || onClose === void 0 ? void 0 : onClose();
                        open && setOpen(false);
                    }, locale: locale, translate: translate, variant: mode !== null && mode !== void 0 ? mode : "single", popoverProps: {
                        id: ariaId,
                        strategy,
                    } },
                    react_1.default.createElement(DatePicker_RDP_1.ReactDayPicker, Object.assign({}, rest, { locale: locale, handleSelect: setValue, selected: value, mode: mode })))))));
});
exports.DatePicker.Standalone = DatePicker_Standalone_1.default;
exports.DatePicker.Input = Date_Input_1.DatePickerInput;
exports.default = exports.DatePicker;
//# sourceMappingURL=DatePicker.js.map