"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const Theme_1 = require("../../../theme/Theme");
const Input_context_1 = require("../Input/Input.context");
const selectedOptionsContext_1 = require("../SelectedOptions/selectedOptionsContext");
const AddNewOption_1 = __importDefault(require("./AddNewOption"));
const FilteredOptionsItem_1 = __importDefault(require("./FilteredOptionsItem"));
const LoadingMessage_1 = __importDefault(require("./LoadingMessage"));
const MaxSelectedMessage_1 = __importDefault(require("./MaxSelectedMessage"));
const NoSearchHitsMessage_1 = __importDefault(require("./NoSearchHitsMessage"));
const filtered_options_util_1 = __importDefault(require("./filtered-options-util"));
const filteredOptionsContext_1 = require("./filteredOptionsContext");
const FilteredOptions = () => {
    const { cn } = (0, Theme_1.useRenameCSS)();
    const { inputProps: { id }, } = (0, Input_context_1.useInputContext)();
    const { allowNewValues, isLoading, isListOpen, filteredOptions, setFilteredOptionsRef, isMouseLastUsedInputDevice, isValueNew, } = (0, filteredOptionsContext_1.useFilteredOptionsContext)();
    const { maxSelected, isMultiSelect } = (0, selectedOptionsContext_1.useSelectedOptionsContext)();
    const shouldRenderNonSelectables = (isMultiSelect && maxSelected.limit) || // Render maxSelected message
        isLoading || // Render loading message
        (!isLoading && filteredOptions.length === 0 && !allowNewValues); // Render no hits message
    const shouldRenderFilteredOptionsList = (allowNewValues && isValueNew && !maxSelected.isLimitReached) || // Render add new option
        filteredOptions.length > 0; // Render filtered options
    return (react_1.default.createElement("div", { className: cn("navds-combobox__list", {
            "navds-combobox__list--closed": !isListOpen,
            "navds-combobox__list--with-hover": isMouseLastUsedInputDevice,
        }), id: filtered_options_util_1.default.getFilteredOptionsId(id), tabIndex: -1 },
        shouldRenderNonSelectables && (react_1.default.createElement("div", { className: cn("navds-combobox__list_non-selectables"), role: "status" },
            isMultiSelect && maxSelected.limit && react_1.default.createElement(MaxSelectedMessage_1.default, null),
            isLoading && react_1.default.createElement(LoadingMessage_1.default, null),
            !isLoading && filteredOptions.length === 0 && !allowNewValues && (react_1.default.createElement(NoSearchHitsMessage_1.default, null)))),
        shouldRenderFilteredOptionsList && (
        /* biome-ignore lint/a11y/useFocusableInteractive: Interaction is not handeled by listbox itself. */
        react_1.default.createElement("ul", { ref: setFilteredOptionsRef, role: "listbox", className: cn("navds-combobox__list-options") },
            isValueNew && !maxSelected.isLimitReached && allowNewValues && (react_1.default.createElement(AddNewOption_1.default, null)),
            filteredOptions.map((option) => (react_1.default.createElement(FilteredOptionsItem_1.default, { key: option.value, option: option })))))));
};
exports.default = FilteredOptions;
//# sourceMappingURL=FilteredOptions.js.map