"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfirmationPanel = void 0;
const clsx_1 = __importDefault(require("clsx"));
const react_1 = __importStar(require("react"));
const Theme_1 = require("../../theme/Theme");
const typography_1 = require("../../typography");
const hooks_1 = require("../../util/hooks");
const checkbox_1 = require("../checkbox");
const useFormField_1 = require("../useFormField");
/**
 * A component that displays a confirmation checkbox with a label.
 * @deprecated Use `Checkbox` instead. See [new pattern documentation](https://aksel.nav.no/monster-maler/soknadsdialog/introside-for-soknadsdialoger#8346a8cb849b) for more information.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/confirmationpanel)
 * @see 🏷️ {@link ConfirmationPanelProps}
 *
 * @example
 * ```jsx
      <ConfirmationPanel
        checked={state}
        label="Ja, jeg samtykker."
        onChange={() => setState((x) => !x)}
      >
        For å komme videre må du gi oss lov til å hente inn og bruke opplysninger
        om deg.
      </ConfirmationPanel>
 * ```
 */
exports.ConfirmationPanel = (0, react_1.forwardRef)((_a, ref) => {
    var { className, children, label } = _a, props = __rest(_a, ["className", "children", "label"]);
    const { cn } = (0, Theme_1.useRenameCSS)();
    const { errorId, showErrorMsg, hasError, size, inputProps } = (0, useFormField_1.useFormField)(props, "confirmation-panel");
    const id = (0, hooks_1.useId)();
    const currentColor = hasError
        ? "danger"
        : props.checked
            ? "success"
            : "warning";
    return (react_1.default.createElement("div", { className: cn("navds-confirmation-panel", "navds-form-field", className, {
            "navds-confirmation-panel--small": size === "small",
            "navds-confirmation-panel--error": hasError,
            "navds-confirmation-panel--checked": !!props.checked,
        }), "data-color": currentColor },
        react_1.default.createElement("div", { className: cn("navds-confirmation-panel__inner") },
            children && (react_1.default.createElement(typography_1.BodyLong, { size: props.size, className: cn("navds-confirmation-panel__content"), id: `confirmation-panel-${id}`, as: "div" }, children)),
            react_1.default.createElement(checkbox_1.Checkbox, Object.assign({ ref: ref }, props, inputProps, { "aria-describedby": (0, clsx_1.default)(inputProps["aria-describedby"], children && `confirmation-panel-${id}`), error: hasError, size: size }), label)),
        react_1.default.createElement("div", { className: cn("navds-form-field__error"), id: errorId, role: "alert" }, showErrorMsg && (react_1.default.createElement(typography_1.ErrorMessage, { size: size, showIcon: true }, props.error)))));
});
exports.default = exports.ConfirmationPanel;
//# sourceMappingURL=ConfirmationPanel.js.map