"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ErrorSummary = void 0;
const react_1 = __importStar(require("react"));
const Theme_1 = require("../../theme/Theme");
const typography_1 = require("../../typography");
const composeEventHandlers_1 = require("../../util/composeEventHandlers");
const hooks_1 = require("../../util/hooks");
const i18n_hooks_1 = require("../../util/i18n/i18n.hooks");
const ErrorSummaryItem_1 = __importDefault(require("./ErrorSummaryItem"));
/**
 * Summary of errors in a form.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/errorsummary)
 * @see 🏷️ {@link ErrorSummaryProps}
 *
 * @example
 * ```jsx
 * <ErrorSummary heading="Du må rette disse feilene før du kan sende inn søknaden:">
 *   <ErrorSummary.Item href="#1">
 *     Felt må fylles ut med alder
 *   </ErrorSummary.Item>
 *   <ErrorSummary.Item href="#2">
 *     Tekstfeltet må ha en godkjent e-post
 *   </ErrorSummary.Item>
 * </ErrorSummary>
 * ```
 */
exports.ErrorSummary = (0, react_1.forwardRef)((_a, ref) => {
    var { children, className, size = "medium", headingTag = "h2", heading } = _a, rest = __rest(_a, ["children", "className", "size", "headingTag", "heading"]);
    const { cn } = (0, Theme_1.useRenameCSS)();
    const translate = (0, i18n_hooks_1.useI18n)("ErrorSummary");
    const wrapperRef = (0, react_1.useRef)(null);
    const headingRef = (0, react_1.useRef)(null);
    const mergedRef = (0, hooks_1.useMergeRefs)(ref, wrapperRef);
    return (react_1.default.createElement("div", Object.assign({ ref: mergedRef }, rest, { className: cn(className, "navds-error-summary", `navds-error-summary--${size}`), tabIndex: -1, onFocus: (0, composeEventHandlers_1.composeEventHandlers)(rest.onFocus, (event) => {
            var _a;
            if (event.target === wrapperRef.current) {
                (_a = headingRef === null || headingRef === void 0 ? void 0 : headingRef.current) === null || _a === void 0 ? void 0 : _a.focus();
            }
        }) }),
        react_1.default.createElement(typography_1.Heading, { className: cn("navds-error-summary__heading"), as: headingTag, size: size === "medium" ? "small" : "xsmall", ref: headingRef, tabIndex: -1 }, heading !== null && heading !== void 0 ? heading : translate("heading")),
        react_1.default.createElement(typography_1.BodyShort, { as: "ul", size: size, className: cn("navds-error-summary__list") }, children)));
});
exports.ErrorSummary.Item = ErrorSummaryItem_1.default;
exports.default = exports.ErrorSummary;
//# sourceMappingURL=ErrorSummary.js.map