"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HelpText = void 0;
const react_1 = __importStar(require("react"));
const popover_1 = require("../popover");
const Theme_1 = require("../theme/Theme");
const composeEventHandlers_1 = require("../util/composeEventHandlers");
const useMergeRefs_1 = require("../util/hooks/useMergeRefs");
const i18n_hooks_1 = require("../util/i18n/i18n.hooks");
const HelpTextIcon_1 = require("./HelpTextIcon");
/**
 * A component that displays a help text button with a popover.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/helptext)
 * @see 🏷️ {@link HelpTextProps}
 *
 * @example
 * ```jsx
 * <HelpText title="Hvor kommer dette fra?">
 *   Informasjonen er hentet fra X sin statistikk fra 2021
 * </HelpText>
 * ```
 */
exports.HelpText = (0, react_1.forwardRef)((_a, ref) => {
    var { className, children, placement, strategy = "absolute", title, onClick, wrapperClassName, "data-color": color = "info" } = _a, rest = __rest(_a, ["className", "children", "placement", "strategy", "title", "onClick", "wrapperClassName", "data-color"]);
    const { cn } = (0, Theme_1.useRenameCSS)();
    const buttonRef = (0, react_1.useRef)(null);
    const mergedRef = (0, useMergeRefs_1.useMergeRefs)(buttonRef, ref);
    const [open, setOpen] = (0, react_1.useState)(false);
    const themeContext = (0, Theme_1.useThemeInternal)(false);
    const translate = (0, i18n_hooks_1.useI18n)("HelpText");
    const titleWithFallback = title || translate("title");
    return (react_1.default.createElement("div", { className: cn("navds-help-text", wrapperClassName), "data-color": color },
        react_1.default.createElement("button", Object.assign({}, rest, { ref: mergedRef, onClick: (0, composeEventHandlers_1.composeEventHandlers)(onClick, () => setOpen((x) => !x)), className: cn(className, "navds-help-text__button"), type: "button", "aria-expanded": open }),
            react_1.default.createElement(HelpTextIcon_1.HelpTextIcon, { title: titleWithFallback }),
            react_1.default.createElement(HelpTextIcon_1.HelpTextIcon, { filled: true, title: titleWithFallback })),
        react_1.default.createElement(popover_1.Popover, { onClose: () => setOpen(false), className: cn("navds-help-text__popover"), open: open, anchorEl: buttonRef.current, placement: placement, strategy: strategy, offset: themeContext ? 8 : 12, arrow: !themeContext },
            react_1.default.createElement(popover_1.Popover.Content, { className: cn("navds-body-short") }, children))));
});
exports.default = exports.HelpText;
//# sourceMappingURL=HelpText.js.map