import { OverridableComponent } from "../../util/types";
import { PrimitiveAsChildProps } from "../base/PrimitiveAsChildProps";
import { StackProps } from "./Stack";
export type HStackProps = PrimitiveAsChildProps & Omit<StackProps, "direction">;
/**
 * Layout-primitive for horizontal flexbox
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/primitives/hstack)
 * @see 🏷️ {@link HStackProps}
 * @see [🤖 OverridableComponent](https://aksel.nav.no/grunnleggende/kode/overridablecomponent) support
 *
 * @example
 * <HStack gap="8">
 *  <MyComponent />
 *  <MyComponent />
 * </HStack>
 *
 * @example
 * // Responsive gap
 * <HStack gap={{xs: "2", md: "6"}}>
 *  <MyComponent />
 *  <MyComponent />
 * </HStack>
 */
export declare const HStack: OverridableComponent<HStackProps, HTMLDivElement>;
export default HStack;
