import { OverridableComponent } from "../../util/types";
import { PrimitiveAsChildProps } from "../base/PrimitiveAsChildProps";
import { StackProps } from "./Stack";
export type VStackProps = PrimitiveAsChildProps & Omit<StackProps, "direction" | "wrap">;
/**
 * Layout-primitive for vetical flexbox
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/primitives/vstack)
 * @see 🏷️ {@link VStackProps}
 * @see [🤖 OverridableComponent](https://aksel.nav.no/grunnleggende/kode/overridablecomponent) support
 *
 * @example
 * <VStack gap="8">
 *  <MyComponent />
 *  <MyComponent />
 * </VStack>
 *
 * @example
 * // Responsive gap
 * <VStack gap={{xs: "2", md: "6"}}>
 *  <MyComponent />
 *  <MyComponent />
 * </VStack>
 */
export declare const VStack: OverridableComponent<VStackProps, HTMLDivElement>;
export default VStack;
