import React from "react";
import { OverridableComponent } from "../util/types";
import { LinkPanelDescriptionProps } from "./LinkPanelDescription";
import { LinkPanelTitleProps } from "./LinkPanelTitle";
export interface LinkPanelProps extends React.AnchorHTMLAttributes<HTMLAnchorElement> {
    /**
     * Panel content
     */
    children?: React.ReactNode;
    /**
     * Adds border to panel if true
     * @default true
     */
    border?: boolean;
}
interface LinkPanelComponentType extends OverridableComponent<LinkPanelProps, HTMLAnchorElement> {
    /**
     * @see 🏷️ {@link LinkPanelDescriptionProps}
     * @see [🤖 OverridableComponent](https://aksel.nav.no/grunnleggende/kode/overridablecomponent) support
     */
    Title: OverridableComponent<LinkPanelTitleProps, HTMLDivElement>;
    /**
     * @see 🏷️ {@link LinkPanelDescriptionProps}
     */
    Description: React.ForwardRefExoticComponent<LinkPanelDescriptionProps & React.RefAttributes<HTMLDivElement>>;
}
/**
 * @deprecated Use `LinkCard` instead. Migrations should be straightforward as the API is similar.
 * @see [📝 LinkCard documentation](https://aksel.nav.no/komponenter/core/linkcard)
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/legacy/linkpanel)
 * @see 🏷️ {@link LinkPanelProps}
 * @see [🤖 OverridableComponent](https://aksel.nav.no/grunnleggende/kode/overridablecomponent) support
 *
 */
export declare const LinkPanelComponent: OverridableComponent<LinkPanelProps, HTMLAnchorElement>;
declare const LinkPanel: LinkPanelComponentType;
export default LinkPanel;
