"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProgressBar = void 0;
const react_1 = __importStar(require("react"));
const Theme_1 = require("../theme/Theme");
const i18n_hooks_1 = require("../util/i18n/i18n.hooks");
/**
 * ProgressBar
 * A component for visualizing progression in a process.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/progress-bar)
 * @see 🏷️ {@link ProgressBarProps}
 *
 * @example
 * // For loading content with an approximate duration in sec.
 * <ProgressBar simulated={{
 *     seconds: 30,
 *     onTimeout: () => console.log("Oops, this is taking more time than expected!")
 *   }}
 * />
 *
 * @example
 * // As a step indicator for forms, questionnaires, etc.
 * <ProgressBar value={2} valueMax={7} />
 */
exports.ProgressBar = (0, react_1.forwardRef)((_a, ref) => {
    var { size = "medium", value = 0, valueMax = 100, "aria-labelledby": ariaLabelledBy, "aria-label": ariaLabel, className, simulated } = _a, rest = __rest(_a, ["size", "value", "valueMax", "aria-labelledby", "aria-label", "className", "simulated"]);
    const { cn } = (0, Theme_1.useRenameCSS)();
    const translateX = 100 - (Math.round(value) / valueMax) * 100;
    const onTimeoutRef = (0, react_1.useRef)();
    onTimeoutRef.current = simulated === null || simulated === void 0 ? void 0 : simulated.onTimeout;
    const translate = (0, i18n_hooks_1.useI18n)("ProgressBar");
    (0, react_1.useEffect)(() => {
        if ((simulated === null || simulated === void 0 ? void 0 : simulated.seconds) && onTimeoutRef.current) {
            const timeout = setTimeout(onTimeoutRef.current, simulated.seconds * 1000);
            return () => clearTimeout(timeout);
        }
    }, [simulated === null || simulated === void 0 ? void 0 : simulated.seconds]);
    return (
    /* biome-ignore lint/a11y/useFocusableInteractive: Progressbar is not interactive. */
    react_1.default.createElement("div", Object.assign({ ref: ref, className: cn("navds-progress-bar", `navds-progress-bar--${size}`, className), "aria-valuemax": (simulated === null || simulated === void 0 ? void 0 : simulated.seconds) ? 0 : Math.round(valueMax), "aria-valuenow": (simulated === null || simulated === void 0 ? void 0 : simulated.seconds) ? 0 : Math.round(value), "aria-valuetext": (simulated === null || simulated === void 0 ? void 0 : simulated.seconds)
            ? translate("progressUnknown", {
                seconds: Math.round(simulated === null || simulated === void 0 ? void 0 : simulated.seconds),
            })
            : translate("progress", {
                current: Math.round(value),
                max: Math.round(valueMax),
            }), 
        // biome-ignore lint/a11y/useAriaPropsForRole: We found that adding valueMin was not needed
        role: "progressbar", "aria-labelledby": ariaLabelledBy, "aria-label": ariaLabel }, rest),
        react_1.default.createElement("div", { className: cn("navds-progress-bar__foreground", {
                "navds-progress-bar__foreground--indeterminate": (simulated === null || simulated === void 0 ? void 0 : simulated.seconds) !== undefined,
            }), style: {
                "--__ac-progress-bar-simulated": (simulated === null || simulated === void 0 ? void 0 : simulated.seconds) !== undefined
                    ? `${simulated === null || simulated === void 0 ? void 0 : simulated.seconds}s`
                    : undefined,
                "--__ac-progress-bar-translate": `-${translateX}%`,
            } })));
});
exports.default = exports.ProgressBar;
//# sourceMappingURL=ProgressBar.js.map