import React from "react";
export interface ReadMoreProps extends React.ButtonHTMLAttributes<HTMLButtonElement> {
    /**
     * Content inside ReadMore.
     */
    children: React.ReactNode;
    /**
     * ReadMore header content.
     */
    header: React.ReactNode;
    /**
     * Opens component if `true`, closes if `false`.
     * Using this prop removes automatic control of open-state.
     */
    open?: boolean;
    /**
     * Initially open.
     * @default false
     */
    defaultOpen?: boolean;
    /**
     * Callback for current open-state
     */
    onOpenChange?: (open: boolean) => void;
    /**
     * Changes fontsize for content.
     * @default "medium"
     */
    size?: "large" | "medium" | "small";
}
/**
 * ReadMore
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/read-more)
 * @see 🏷️ {@link ReadMoreProps}
 *
 * @example
 * // Default
 * <ReadMore header="Dette regnes som helsemessige begrensninger">
 *  Med helsemessige begrensninger mener vi funksjonshemming, sykdom...
 * </ReadMore>
 *
 * @example
 * // Litt mindre versjon
 * <ReadMore size="small" header="Dette regnes som helsemessige begrensninger">
 *   Med helsemessige begrensninger mener vi funksjonshemming, sykdom...
 * </ReadMore>
 */
export declare const ReadMore: React.ForwardRefExoticComponent<ReadMoreProps & React.RefAttributes<HTMLButtonElement>>;
export default ReadMore;
