import React from "react";
export interface SkeletonProps extends React.HTMLAttributes<HTMLDivElement> {
    children?: React.ReactNode;
    /**
     * @default text
     */
    variant?: "circle" | "rectangle" | "rounded" | "text";
    /**
     * When not inferring height from children, you must specify height
     */
    height?: number | string;
    /**
     * When not inferring width from children, you must specify width
     */
    width?: number | string;
    /**
     * Overrides html-tag
     * @default "div"
     */
    as?: "div" | "span";
}
/**
 * Simple skeleton loader
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/skeleton)
 * @see 🏷️ {@link SkeletonProps}
 * @example
 * ```jsx
 * <Skeleton variant="circle" height="5rem" width="5rem" />
 * ```
 */
export declare const Skeleton: React.ForwardRefExoticComponent<SkeletonProps & React.RefAttributes<HTMLDivElement>>;
export default Skeleton;
