"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Stepper = void 0;
const react_1 = __importStar(require("react"));
const Theme_1 = require("../theme/Theme");
const Step_1 = __importDefault(require("./Step"));
const context_1 = require("./context");
/**
 * A component that displays a stepper with clickable steps.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/stepper)
 * @see 🏷️ {@link StepperProps}
 *
 * @example
 * ```jsx
 * <>
 *   <Heading size="medium" spacing level="2" id="stepper-heading">
 *     Søknadssteg
 *   </Heading>
 *   <Stepper
 *     aria-labelledby="stepper-heading"
 *     activeStep={activeStep}
 *     onStepChange={setActiveStep}
 *   >
 *     <Stepper.Step href="#">Start søknad</Stepper.Step>
 *     <Stepper.Step href="#">Saksopplysninger</Stepper.Step>
 *     <Stepper.Step href="#">Vedlegg</Stepper.Step>
 *   </Stepper>
 * </>
 * ```
 */
exports.Stepper = (0, react_1.forwardRef)((_a, ref) => {
    var { children, className, activeStep, orientation = "vertical", onStepChange = () => { }, interactive = true } = _a, rest = __rest(_a, ["children", "className", "activeStep", "orientation", "onStepChange", "interactive"]);
    const { cn } = (0, Theme_1.useRenameCSS)();
    activeStep = activeStep - 1;
    return (react_1.default.createElement("ol", Object.assign({}, rest, { ref: ref, className: cn("navds-stepper", orientation === "horizontal" ? "navds-stepper--horizontal" : "", className), "data-orientation": orientation }), react_1.default.Children.map(children, (step, index) => {
        var _a, _b, _c;
        const stepProps = react_1.default.isValidElement(step) ? step.props : {};
        const isInteractive = (_a = stepProps.interactive) !== null && _a !== void 0 ? _a : interactive;
        return (react_1.default.createElement("li", { className: cn("navds-stepper__item", {
                /* TODO: Remove these 3 classNames in darkmode update */
                "navds-stepper__item--behind": activeStep > index,
                "navds-stepper__item--completed": stepProps.completed,
                "navds-stepper__item--non-interactive": !isInteractive,
            }), "data-color": isInteractive ? undefined : "neutral", key: index + ((_c = (_b = children === null || children === void 0 ? void 0 : children.toString) === null || _b === void 0 ? void 0 : _b.call(children)) !== null && _c !== void 0 ? _c : "") },
            react_1.default.createElement("span", { className: cn("navds-stepper__line navds-stepper__line--1") }),
            react_1.default.createElement(context_1.StepperContextProvider, { interactive: interactive, activeStep: activeStep, lastIndex: react_1.default.Children.count(children), index: index, onStepChange: onStepChange, orientation: orientation }, step),
            react_1.default.createElement("span", { className: cn("navds-stepper__line navds-stepper__line--2") })));
    })));
});
exports.Stepper.Step = Step_1.default;
exports.default = exports.Stepper;
//# sourceMappingURL=Stepper.js.map