import React from "react";
import { TabsProps } from "./Tabs.types";
import Tab from "./parts/tab/Tab";
import TabList from "./parts/tablist/TabList";
import TabPanel from "./parts/tabpanel/TabPanel";
interface TabsComponent extends React.ForwardRefExoticComponent<TabsProps & React.RefAttributes<HTMLDivElement>> {
    /**
     * @see 🏷️ {@link TabProps}
     * @see [🤖 OverridableComponent](https://aksel.nav.no/grunnleggende/kode/overridablecomponent) support
     */
    Tab: typeof Tab;
    /**
     * @see 🏷️ {@link TabListProps}
     */
    List: typeof TabList;
    /**
     * @see 🏷️ {@link TabPanelProps}
     */
    Panel: typeof TabPanel;
}
/**
 * A component that displays a set of tabs that can be used to switch between different views.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/tabs)
 * @see 🏷️ {@link TabsProps}
 *
 * @example
 * ```jsx
 * <Tabs defaultValue="logg">
 *   <Tabs.List>
 *     <Tabs.Tab value="logg" label="Logg" />
 *     <Tabs.Tab value="inbox" label="Inbox" />
 *     <Tabs.Tab value="sendt" label="Sendt" />
 *   </Tabs.List>
 *   <Tabs.Panel value="logg">
 *     Logg-tab
 *   </Tabs.Panel>
 *   <Tabs.Panel value="inbox">
 *     Inbox-tab
 *   </Tabs.Panel>
 *   <Tabs.Panel value="sendt">
 *     Sendt-tab
 *   </Tabs.Panel>
 * </Tabs>
 * ```
 */
export declare const Tabs: TabsComponent;
export default Tabs;
