"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tabs = void 0;
const react_1 = __importStar(require("react"));
const Theme_1 = require("../theme/Theme");
const Tabs_context_1 = require("./Tabs.context");
const Tab_1 = __importDefault(require("./parts/tab/Tab"));
const TabList_1 = __importDefault(require("./parts/tablist/TabList"));
const TabPanel_1 = __importDefault(require("./parts/tabpanel/TabPanel"));
const useTabs_1 = require("./useTabs");
/**
 * A component that displays a set of tabs that can be used to switch between different views.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/tabs)
 * @see 🏷️ {@link TabsProps}
 *
 * @example
 * ```jsx
 * <Tabs defaultValue="logg">
 *   <Tabs.List>
 *     <Tabs.Tab value="logg" label="Logg" />
 *     <Tabs.Tab value="inbox" label="Inbox" />
 *     <Tabs.Tab value="sendt" label="Sendt" />
 *   </Tabs.List>
 *   <Tabs.Panel value="logg">
 *     Logg-tab
 *   </Tabs.Panel>
 *   <Tabs.Panel value="inbox">
 *     Inbox-tab
 *   </Tabs.Panel>
 *   <Tabs.Panel value="sendt">
 *     Sendt-tab
 *   </Tabs.Panel>
 * </Tabs>
 * ```
 */
exports.Tabs = (0, react_1.forwardRef)((_a, ref) => {
    var { className, children, size = "medium", defaultValue = "", value, onChange, id, selectionFollowsFocus = false, loop = true, iconPosition = "left", fill = false } = _a, rest = __rest(_a, ["className", "children", "size", "defaultValue", "value", "onChange", "id", "selectionFollowsFocus", "loop", "iconPosition", "fill"]);
    const { cn } = (0, Theme_1.useRenameCSS)();
    const descendants = (0, Tabs_context_1.useTabsDescendants)();
    const tabsContext = (0, useTabs_1.useTabs)({ defaultValue, value, onChange, id });
    /**
     * TabsProvider handles memoization of context values, so we can safely skip it here.
     */
    const context = Object.assign(Object.assign({}, tabsContext), { selectionFollowsFocus,
        loop,
        size,
        iconPosition,
        fill });
    return (react_1.default.createElement(Tabs_context_1.TabsDescendantsProvider, { value: descendants },
        react_1.default.createElement(Tabs_context_1.TabsProvider, Object.assign({}, context),
            react_1.default.createElement("div", Object.assign({ ref: ref }, rest, { id: id, className: cn("navds-tabs", className, `navds-tabs--${size}`) }), children))));
});
exports.Tabs.Tab = Tab_1.default;
exports.Tabs.List = TabList_1.default;
exports.Tabs.Panel = TabPanel_1.default;
exports.default = exports.Tabs;
//# sourceMappingURL=Tabs.js.map