"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ToggleGroup = void 0;
const clsx_1 = __importDefault(require("clsx"));
const react_1 = __importStar(require("react"));
const Theme_1 = require("../theme/Theme");
const typography_1 = require("../typography");
const util_1 = require("../util");
const ToggleGroup_context_1 = require("./ToggleGroup.context");
const ToggleItem_1 = __importDefault(require("./parts/ToggleItem"));
const useToggleGroup_1 = require("./useToggleGroup");
/**
 * A component that displays a group of toggle buttons.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/toggle-group)
 * @see 🏷️ {@link ToggleGroupProps}
 *
 * @example
 * ```jsx
 * <ToggleGroup defaultValue="lest" onChange={console.log} size="small">
 *   <ToggleGroup.Item value="ulest" label="Ulest" />
 *   <ToggleGroup.Item value="lest" label="Leste" />
 *   <ToggleGroup.Item value="sendt" label="Sendt" />
 * </ToggleGroup>
 * ```
 */
exports.ToggleGroup = (0, react_1.forwardRef)((_a, ref) => {
    var { className, children, onChange, size = "medium", label, value, defaultValue, "aria-describedby": userDescribedby, variant, fill = false, "data-color": color } = _a, rest = __rest(_a, ["className", "children", "onChange", "size", "label", "value", "defaultValue", "aria-describedby", "variant", "fill", "data-color"]);
    const { cn } = (0, Theme_1.useRenameCSS)();
    const themeContext = (0, Theme_1.useThemeInternal)(false);
    const descendants = (0, ToggleGroup_context_1.useToggleGroupDescendants)();
    const toggleGroupContext = (0, useToggleGroup_1.useToggleGroup)({
        defaultValue,
        value,
        onChange,
    });
    /**
     * ToggleGroupProvider handles memoization.
     */
    const context = Object.assign(Object.assign({}, toggleGroupContext), { size });
    const labelId = (0, util_1.useId)();
    if (!value && !defaultValue) {
        console.error("ToggleGroup without value or defaultvalue is not allowed");
    }
    if (!value && !defaultValue) {
        console.error("ToggleGroup needs either a value or defaultValue");
    }
    let localVariant;
    if (themeContext) {
        localVariant = variant;
    }
    else {
        localVariant = variant !== null && variant !== void 0 ? variant : "action";
    }
    return (react_1.default.createElement(ToggleGroup_context_1.ToggleGroupDescendantsProvider, { value: descendants },
        react_1.default.createElement(ToggleGroup_context_1.ToggleGroupProvider, Object.assign({}, context),
            react_1.default.createElement("div", { className: cn("navds-toggle-group__wrapper", className, {
                    "navds-toggle-group__wrapper--fill": fill,
                }), "data-color": color !== null && color !== void 0 ? color : variantToColor(localVariant) },
                label && (react_1.default.createElement(typography_1.Label, { size: size, className: cn("navds-toggle-group__label"), id: labelId }, label)),
                react_1.default.createElement("div", Object.assign({}, rest, { ref: ref, className: cn("navds-toggle-group", `navds-toggle-group--${size}`, { [`navds-toggle-group--${localVariant}`]: localVariant }), "aria-describedby": (0, clsx_1.default)(userDescribedby, !!label && labelId) || undefined, role: "radiogroup" }), children)))));
});
function variantToColor(variant) {
    switch (variant) {
        case "action":
            return "accent";
        case "neutral":
            return "neutral";
        default:
            return undefined;
    }
}
exports.ToggleGroup.Item = ToggleItem_1.default;
exports.default = exports.ToggleGroup;
//# sourceMappingURL=ToggleGroup.js.map