"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useCallbackRef = useCallbackRef;
const react_1 = require("react");
/**
 * A custom hook that converts a callback to a ref to avoid triggering re-renders when passed as a
 * prop or avoid re-executing effects when passed as a dependency
 * https://github.com/radix-ui/primitives/blob/main/packages/react/use-callback-ref/src/useCallbackRef.tsx
 */
function useCallbackRef(callback, deps = []) {
    const callbackRef = (0, react_1.useRef)(callback);
    (0, react_1.useEffect)(() => {
        callbackRef.current = callback;
    });
    // eslint-disable-next-line react-hooks/exhaustive-deps
    return (0, react_1.useCallback)(((...args) => { var _a; return (_a = callbackRef.current) === null || _a === void 0 ? void 0 : _a.call(callbackRef, ...args); }), deps);
}
//# sourceMappingURL=useCallbackRef.js.map