import React from "react";
import { useRenameCSS } from "../../../theme/Theme.js";
import { useInputContext } from "../Input/Input.context.js";
import { useSelectedOptionsContext } from "../SelectedOptions/selectedOptionsContext.js";
import AddNewOption from "./AddNewOption.js";
import FilteredOptionsItem from "./FilteredOptionsItem.js";
import LoadingMessage from "./LoadingMessage.js";
import MaxSelectedMessage from "./MaxSelectedMessage.js";
import NoSearchHitsMessage from "./NoSearchHitsMessage.js";
import filteredOptionsUtil from "./filtered-options-util.js";
import { useFilteredOptionsContext } from "./filteredOptionsContext.js";
const FilteredOptions = () => {
    const { cn } = useRenameCSS();
    const { inputProps: { id }, } = useInputContext();
    const { allowNewValues, isLoading, isListOpen, filteredOptions, setFilteredOptionsRef, isMouseLastUsedInputDevice, isValueNew, } = useFilteredOptionsContext();
    const { maxSelected, isMultiSelect } = useSelectedOptionsContext();
    const shouldRenderNonSelectables = (isMultiSelect && maxSelected.limit) || // Render maxSelected message
        isLoading || // Render loading message
        (!isLoading && filteredOptions.length === 0 && !allowNewValues); // Render no hits message
    const shouldRenderFilteredOptionsList = (allowNewValues && isValueNew && !maxSelected.isLimitReached) || // Render add new option
        filteredOptions.length > 0; // Render filtered options
    return (React.createElement("div", { className: cn("navds-combobox__list", {
            "navds-combobox__list--closed": !isListOpen,
            "navds-combobox__list--with-hover": isMouseLastUsedInputDevice,
        }), id: filteredOptionsUtil.getFilteredOptionsId(id), tabIndex: -1 },
        shouldRenderNonSelectables && (React.createElement("div", { className: cn("navds-combobox__list_non-selectables"), role: "status" },
            isMultiSelect && maxSelected.limit && React.createElement(MaxSelectedMessage, null),
            isLoading && React.createElement(LoadingMessage, null),
            !isLoading && filteredOptions.length === 0 && !allowNewValues && (React.createElement(NoSearchHitsMessage, null)))),
        shouldRenderFilteredOptionsList && (
        /* biome-ignore lint/a11y/useFocusableInteractive: Interaction is not handeled by listbox itself. */
        React.createElement("ul", { ref: setFilteredOptionsRef, role: "listbox", className: cn("navds-combobox__list-options") },
            isValueNew && !maxSelected.isLimitReached && allowNewValues && (React.createElement(AddNewOption, null)),
            filteredOptions.map((option) => (React.createElement(FilteredOptionsItem, { key: option.value, option: option })))))));
};
export default FilteredOptions;
//# sourceMappingURL=FilteredOptions.js.map