import { useState } from "react";
const useVirtualFocus = (containerRef) => {
    const [activeElement, setActiveElement] = useState(undefined);
    const getListOfAllChildren = () => { var _a; return Array.from((_a = containerRef === null || containerRef === void 0 ? void 0 : containerRef.children) !== null && _a !== void 0 ? _a : []); };
    const getElementsAbleToReceiveFocus = () => getListOfAllChildren().filter((child) => child.getAttribute("data-no-focus") !== "true");
    const getElementById = (id) => getListOfAllChildren().find((element) => element.id === id);
    const isFocusOnTheTop = () => activeElement
        ? getElementsAbleToReceiveFocus().indexOf(activeElement) === 0
        : false;
    const isFocusOnTheBottom = () => {
        const elementsAbleToReceiveFocus = getElementsAbleToReceiveFocus();
        return activeElement
            ? elementsAbleToReceiveFocus.indexOf(activeElement) ===
                elementsAbleToReceiveFocus.length - 1
            : false;
    };
    const setActiveAndScrollToElement = (element) => {
        var _a;
        setActiveElement(element);
        (_a = element === null || element === void 0 ? void 0 : element.scrollIntoView) === null || _a === void 0 ? void 0 : _a.call(element, { block: "nearest" });
    };
    const moveFocusUp = () => {
        if (!activeElement) {
            return;
        }
        const elementsAbleToReceiveFocus = getElementsAbleToReceiveFocus();
        const _currentIndex = elementsAbleToReceiveFocus.indexOf(activeElement);
        const elementAbove = elementsAbleToReceiveFocus[_currentIndex - 1];
        if (_currentIndex === 0) {
            setActiveElement(undefined);
        }
        else {
            setActiveAndScrollToElement(elementAbove);
        }
    };
    const moveFocusDown = () => {
        const elementsAbleToReceiveFocus = getElementsAbleToReceiveFocus();
        if (!activeElement) {
            setActiveAndScrollToElement(elementsAbleToReceiveFocus[0]);
            return;
        }
        const _currentIndex = elementsAbleToReceiveFocus.indexOf(activeElement);
        if (_currentIndex === elementsAbleToReceiveFocus.length - 1) {
            return;
        }
        setActiveAndScrollToElement(elementsAbleToReceiveFocus[_currentIndex + 1]);
    };
    const resetFocus = () => setActiveElement(undefined);
    const moveFocusToTop = () => {
        const elementsAbleToReceiveFocus = getElementsAbleToReceiveFocus();
        setActiveAndScrollToElement(elementsAbleToReceiveFocus[0]);
    };
    const moveFocusToBottom = () => {
        const elementsAbleToReceiveFocus = getElementsAbleToReceiveFocus();
        setActiveAndScrollToElement(elementsAbleToReceiveFocus[elementsAbleToReceiveFocus.length - 1]);
    };
    const moveFocusToElement = (id) => {
        const _element = getElementsAbleToReceiveFocus().find((_focusableElement) => _focusableElement.getAttribute("id") === id);
        if (_element) {
            setActiveElement(_element);
        }
    };
    const moveFocusUpBy = (numberOfElements) => {
        if (!activeElement) {
            return;
        }
        const elementsAbleToReceiveFocus = getElementsAbleToReceiveFocus();
        const currentIndex = elementsAbleToReceiveFocus.indexOf(activeElement);
        const newIndex = Math.max(currentIndex - numberOfElements, 0);
        setActiveAndScrollToElement(elementsAbleToReceiveFocus[newIndex]);
    };
    const moveFocusDownBy = (numberOfElements) => {
        const elementsAbleToReceiveFocus = getElementsAbleToReceiveFocus();
        const currentIndex = activeElement
            ? elementsAbleToReceiveFocus.indexOf(activeElement)
            : -1;
        const newIndex = Math.min(currentIndex + numberOfElements, elementsAbleToReceiveFocus.length - 1);
        setActiveAndScrollToElement(elementsAbleToReceiveFocus[newIndex]);
    };
    return {
        activeElement,
        getElementById,
        isFocusOnTheTop,
        isFocusOnTheBottom,
        moveFocusUp,
        moveFocusDown,
        moveFocusToElement,
        moveFocusToTop,
        moveFocusToBottom,
        moveFocusUpBy,
        moveFocusDownBy,
        resetFocus,
    };
};
export default useVirtualFocus;
//# sourceMappingURL=useVirtualFocus.js.map