import React, { HTMLAttributes } from "react";
import ErrorSummaryItem from "./ErrorSummaryItem.js";
export interface ErrorSummaryProps extends Omit<HTMLAttributes<HTMLDivElement>, "tabIndex"> {
    /**
     * Collection of `ErrorSummary.Item`.
     */
    children: React.ReactNode;
    /**
     * Changes padding and font-sizes.
     * @default "medium"
     */
    size?: "medium" | "small";
    /**
     * Heading above links.
     * @default "Du må rette disse feilene før du kan fortsette:"
     */
    heading?: React.ReactNode;
    /**
     * Allows setting a different HTML h-tag.
     * @default "h2"
     */
    headingTag?: React.ElementType<any>;
}
interface ErrorSummaryComponent extends React.ForwardRefExoticComponent<ErrorSummaryProps & React.RefAttributes<HTMLDivElement>> {
    /**
     * Error message with link to field.
     *
     * @see [🤖 OverridableComponent](https://aksel.nav.no/grunnleggende/kode/overridablecomponent) support
     *
     * @example
     * ```jsx
     * <ErrorSummary.Item href="#id-til-alderfelt">
     *   Felt må fylles ut med alder
     * </ErrorSummary.Item>
     * ```
     */
    Item: typeof ErrorSummaryItem;
}
/**
 * Summary of errors in a form.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/errorsummary)
 * @see 🏷️ {@link ErrorSummaryProps}
 *
 * @example
 * ```jsx
 * <ErrorSummary heading="Du må rette disse feilene før du kan sende inn søknaden:">
 *   <ErrorSummary.Item href="#1">
 *     Felt må fylles ut med alder
 *   </ErrorSummary.Item>
 *   <ErrorSummary.Item href="#2">
 *     Tekstfeltet må ha en godkjent e-post
 *   </ErrorSummary.Item>
 * </ErrorSummary>
 * ```
 */
export declare const ErrorSummary: ErrorSummaryComponent;
export default ErrorSummary;
