import React, { HTMLAttributes } from "react";
export interface GuidePanelProps extends HTMLAttributes<HTMLDivElement> {
    /**
     * GuidePanel content
     */
    children: React.ReactNode;
    /**
     * Custom svg/img element
     */
    illustration?: React.ReactNode;
    /**
     * Render illustation above content
     * @default true on mobile (<480px)
     */
    poster?: boolean;
}
/**
 * A component for guiding users on the website
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/guidepanel)
 * @see 🏷️ {@link GuidePanelProps}
 *
 * @example
 * ```jsx
 * <GuidePanel>
 *   Saksbehandlingstiden varierer fra kommune til kommune. Hvis det går mer
 *   enn X måneder siden du søkte, skal du få brev om at saksbehandlingstiden
 *   er forlenget.
 * </GuidePanel>
 * ```
 */
export declare const GuidePanel: React.ForwardRefExoticComponent<GuidePanelProps & React.RefAttributes<HTMLDivElement>>;
export default GuidePanel;
