import React, { SVGProps } from "react";
import { AkselColor } from "../types/index.js";
export interface LoaderProps extends Omit<SVGProps<SVGSVGElement>, "ref"> {
    /**
     * Changes Loader width/height
     * 88px | 64px | 40px | 32px | 24px | 20px | 16px
     * @default "medium"
     */
    size?: "3xlarge" | "2xlarge" | "xlarge" | "large" | "medium" | "small" | "xsmall";
    /**
     * Title prop on svg
     * @default "Venter…"
     */
    title?: React.ReactNode;
    /**
     * Sets svg-background to transparent
     * @default false
     */
    transparent?: boolean;
    /**
     * Colored variants for Loader
     * @default "neutral"
     */
    variant?: "neutral" | "interaction" | "inverted";
    /**
     * Overrides loader-color
     */
    "data-color"?: AkselColor;
}
export type LoaderType = React.ForwardRefExoticComponent<LoaderProps & React.RefAttributes<SVGSVGElement>>;
/**
 * A component that displays a loading spinner.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/loader)
 * @see 🏷️ {@link LoaderProps}
 *
 * @example
 * ```jsx
 * <Loader size="3xlarge" title="Venter…" />
 * ```
 */
export declare const Loader: LoaderType;
export default Loader;
