var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { forwardRef, useEffect, useRef } from "react";
import { useRenameCSS } from "../theme/Theme.js";
import { useI18n } from "../util/i18n/i18n.hooks.js";
/**
 * ProgressBar
 * A component for visualizing progression in a process.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/progress-bar)
 * @see 🏷️ {@link ProgressBarProps}
 *
 * @example
 * // For loading content with an approximate duration in sec.
 * <ProgressBar simulated={{
 *     seconds: 30,
 *     onTimeout: () => console.log("Oops, this is taking more time than expected!")
 *   }}
 * />
 *
 * @example
 * // As a step indicator for forms, questionnaires, etc.
 * <ProgressBar value={2} valueMax={7} />
 */
export const ProgressBar = forwardRef((_a, ref) => {
    var { size = "medium", value = 0, valueMax = 100, "aria-labelledby": ariaLabelledBy, "aria-label": ariaLabel, className, simulated } = _a, rest = __rest(_a, ["size", "value", "valueMax", "aria-labelledby", "aria-label", "className", "simulated"]);
    const { cn } = useRenameCSS();
    const translateX = 100 - (Math.round(value) / valueMax) * 100;
    const onTimeoutRef = useRef();
    onTimeoutRef.current = simulated === null || simulated === void 0 ? void 0 : simulated.onTimeout;
    const translate = useI18n("ProgressBar");
    useEffect(() => {
        if ((simulated === null || simulated === void 0 ? void 0 : simulated.seconds) && onTimeoutRef.current) {
            const timeout = setTimeout(onTimeoutRef.current, simulated.seconds * 1000);
            return () => clearTimeout(timeout);
        }
    }, [simulated === null || simulated === void 0 ? void 0 : simulated.seconds]);
    return (
    /* biome-ignore lint/a11y/useFocusableInteractive: Progressbar is not interactive. */
    React.createElement("div", Object.assign({ ref: ref, className: cn("navds-progress-bar", `navds-progress-bar--${size}`, className), "aria-valuemax": (simulated === null || simulated === void 0 ? void 0 : simulated.seconds) ? 0 : Math.round(valueMax), "aria-valuenow": (simulated === null || simulated === void 0 ? void 0 : simulated.seconds) ? 0 : Math.round(value), "aria-valuetext": (simulated === null || simulated === void 0 ? void 0 : simulated.seconds)
            ? translate("progressUnknown", {
                seconds: Math.round(simulated === null || simulated === void 0 ? void 0 : simulated.seconds),
            })
            : translate("progress", {
                current: Math.round(value),
                max: Math.round(valueMax),
            }), 
        // biome-ignore lint/a11y/useAriaPropsForRole: We found that adding valueMin was not needed
        role: "progressbar", "aria-labelledby": ariaLabelledBy, "aria-label": ariaLabel }, rest),
        React.createElement("div", { className: cn("navds-progress-bar__foreground", {
                "navds-progress-bar__foreground--indeterminate": (simulated === null || simulated === void 0 ? void 0 : simulated.seconds) !== undefined,
            }), style: {
                "--__ac-progress-bar-simulated": (simulated === null || simulated === void 0 ? void 0 : simulated.seconds) !== undefined
                    ? `${simulated === null || simulated === void 0 ? void 0 : simulated.seconds}s`
                    : undefined,
                "--__ac-progress-bar-translate": `-${translateX}%`,
            } })));
});
export default ProgressBar;
//# sourceMappingURL=ProgressBar.js.map