var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { forwardRef } from "react";
import { useRenameCSS } from "../theme/Theme.js";
import { BodyShort } from "../typography/index.js";
/**
 * A component that displays a small label with a text and a background color.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/tag)
 * @see 🏷️ {@link TagProps}
 *
 * @example
 * ```jsx
 * <Tag variant="success">Success</Tag>
 * ```
 */
export const Tag = forwardRef((_a, ref) => {
    var { children, className, variant, size = "medium", icon, "data-color": color } = _a, rest = __rest(_a, ["children", "className", "variant", "size", "icon", "data-color"]);
    const { cn } = useRenameCSS();
    const filledVariant = (variant === null || variant === void 0 ? void 0 : variant.endsWith("-filled")) && "strong";
    const moderateVariant = (variant === null || variant === void 0 ? void 0 : variant.endsWith("-moderate")) && "moderate";
    return (React.createElement(BodyShort, Object.assign({ "data-color": color !== null && color !== void 0 ? color : variantToColor(variant), "data-variant": filledVariant || moderateVariant || "outline" }, rest, { ref: ref, as: "span", size: size === "medium" ? "medium" : "small", className: cn("navds-tag", className, `navds-tag--${variant}`, `navds-tag--${size}`) }),
        icon && React.createElement("span", { className: cn("navds-tag__icon--left") }, icon),
        children));
});
function variantToColor(variant) {
    switch (variant) {
        case "warning":
        case "warning-filled":
        case "warning-moderate":
            return "warning";
        case "error":
        case "error-filled":
        case "error-moderate":
            return "danger";
        case "info":
        case "info-filled":
        case "info-moderate":
        case "alt3":
        case "alt3-filled":
        case "alt3-moderate":
            return "info";
        case "success":
        case "success-filled":
        case "success-moderate":
            return "success";
        case "neutral":
        case "neutral-filled":
        case "neutral-moderate":
            return "neutral";
        case "alt1":
        case "alt1-filled":
        case "alt1-moderate":
            return "meta-purple";
        case "alt2":
        case "alt2-filled":
        case "alt2-moderate":
            return "meta-lime";
        default:
            return "neutral";
    }
}
export default Tag;
//# sourceMappingURL=Tag.js.map