import React from "react";
import { OverridableComponent } from "../util/types/index.js";
import { TypoProps } from "./types.js";
export interface BodyLongProps extends TypoProps, React.HTMLAttributes<HTMLParagraphElement> {
    /**
     * large: 20px, medium: 18px, small: 16px.
     * @default "medium"
     */
    size?: "large" | "medium" | "small";
    /**
     * Text.
     */
    children: React.ReactNode;
}
/**
 * Part of a set of components for displaying text with consistent typography.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/typography)
 * @see 🏷️ {@link BodyLongProps}
 * @see [🤖 OverridableComponent](https://aksel.nav.no/grunnleggende/kode/overridablecomponent) support
 *
 * @example
 * ```jsx
 * <BodyLong>
 *   Hvis du ikke bor sammen med begge foreldrene dine,
 *   kan du ha rett til barnebidrag fra en eller begge foreldre mens du
 *   fullfører videregående skole eller tilsvarende.
 * </BodyLong>
 * ```
 */
export declare const BodyLong: OverridableComponent<BodyLongProps, HTMLParagraphElement>;
export default BodyLong;
