import React from "react";
import { OverridableComponent } from "../util/types/index.js";
import { TypoProps } from "./types.js";
export interface BodyShortProps extends TypoProps, React.HTMLAttributes<HTMLParagraphElement> {
    /**
     * large: 20px, medium: 18px, small: 16px.
     * @default "medium"
     */
    size?: "large" | "medium" | "small";
    /**
     * Paragraph text.
     */
    children: React.ReactNode;
}
/**
 * Part of a set of components for displaying text with consistent typography.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/typography)
 * @see 🏷️ {@link BodyShortProps}
 * @see [🤖 OverridableComponent](https://aksel.nav.no/grunnleggende/kode/overridablecomponent) support
 *
 * @example
 * ```jsx
 * <BodyShort>
 *   Du må gjøre en filtrering for å se brukere i listen.
 * </BodyShort>
 * ```
 */
export declare const BodyShort: OverridableComponent<BodyShortProps, HTMLParagraphElement>;
export default BodyShort;
