import React from "react";
import { OverridableComponent } from "../util/types/index.js";
import { TypoProps } from "./types.js";
export interface DetailProps extends TypoProps, React.HTMLAttributes<HTMLParagraphElement> {
    /**
     * @deprecated Medium is now the same as small.
     */
    size?: "medium" | "small";
    /**
     * Text.
     */
    children: React.ReactNode;
    /**
     * ALL CAPS.
     */
    uppercase?: boolean;
}
/**
 * Part of a set of components for displaying text with consistent typography.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/typography)
 * @see 🏷️ {@link DetailProps}
 * @see [🤖 OverridableComponent](https://aksel.nav.no/grunnleggende/kode/overridablecomponent) support
 *
 * @example
 * ```jsx
 * <Detail>
 *   Du må gjøre en filtrering for å se brukere i listen.
 * </Detail>
 * ```
 */
export declare const Detail: OverridableComponent<DetailProps, HTMLParagraphElement>;
export default Detail;
