import React from "react";
import { OverridableComponent } from "../util/types/index.js";
import { TypoProps } from "./types.js";
export interface ErrorMessageProps extends Pick<TypoProps, "spacing">, React.HTMLAttributes<HTMLParagraphElement> {
    /**
     * medium: 18px, small: 16px.
     * @default "medium"
     */
    size?: "medium" | "small";
    /**
     * Error text.
     */
    children: React.ReactNode;
    /**
     * Render a triangular warning icon.
     */
    showIcon?: boolean;
}
/**
 * Part of a set of components for displaying text with consistent typography.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/typography)
 * @see 🏷️ {@link ErrorMessageProps}
 * @see [🤖 OverridableComponent](https://aksel.nav.no/grunnleggende/kode/overridablecomponent) support
 *
 * @example
 * ```jsx
 * <ErrorMessage>
 *   Du må fylle ut: Oppgi årsaken til at du har ventet mer enn 6 måneder med å søke om refusjon
 * </ErrorMessage>
 * ```
 */
export declare const ErrorMessage: OverridableComponent<ErrorMessageProps, HTMLParagraphElement>;
export default ErrorMessage;
