import React from "react";
import { OverridableComponent } from "../util/types/index.js";
import { TypoProps } from "./types.js";
export interface HeadingProps extends Pick<TypoProps, "spacing" | "visuallyHidden" | "align" | "textColor">, React.HTMLAttributes<HTMLHeadingElement> {
    /**
     * Heading level.
     * @default "1"
     */
    level?: "1" | "2" | "3" | "4" | "5" | "6";
    /**
     * xlarge: 40px, large: 32px, medium: 24px, small: 20px, xsmall: 18px.
     */
    size: "xlarge" | "large" | "medium" | "small" | "xsmall";
    /**
     * Heading text.
     */
    children: React.ReactNode;
}
/**
 * Part of a set of components for displaying text with consistent typography.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/typography)
 * @see 🏷️ {@link HeadingProps}
 * @see [🤖 OverridableComponent](https://aksel.nav.no/grunnleggende/kode/overridablecomponent) support
 *
 * @example
 * ```jsx
 * <Heading level="1" size="xlarge">
 *   Hva kan vi hjelpe deg med?
 * </Heading>
 * ```
 */
export declare const Heading: OverridableComponent<HeadingProps, HTMLHeadingElement>;
export default Heading;
